@@ -9,7 +9,7 @@ import json
 __author__ = '@titom73'
 __email__ = 'tom@inetsix.net'
 __date__ = '2022-03-16'
-__version__ = '0.5.1'
+__version__ = '0.7.0'
 
 __all__ = ["CvpAuthenticationItem", "CvFeatureManager", "EOSDownloader", "ObjectDownloader", "reverse"]
 
@@ -19,16 +19,17 @@ ARISTA_SOFTWARE_FOLDER_TREE = "https://www.arista.com/custom_data/api/cvp/getFol
 
 ARISTA_DOWNLOAD_URL = "https://www.arista.com/custom_data/api/cvp/getDownloadLink/"
 
-MSG_TOKEN_EXPIRED = """
-The API token has expired. Please visit arista.com, click on your profile and
+MSG_TOKEN_EXPIRED = """The API token has expired. Please visit arista.com, click on your profile and
 select Regenerate Token then re-run the script with the new token.
 """
 
-MSG_TOKEN_INVALID = """
-The API token is incorrect. Please visit arista.com, click on your profile and
+MSG_TOKEN_INVALID = """The API token is incorrect. Please visit arista.com, click on your profile and
 check the Access Token. Then re-run the script with the correct token.
 """
 
+MSG_INVALID_DATA = """Invalid data returned by server
+"""
+
 EVE_QEMU_FOLDER_PATH = '/opt/unetlab/addons/qemu/'
 
 
